Pipelines
=========

.. raw:: html

    <div id="box" style="display: flex; flex-flow: wrap;">
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgsgermlinemulticallers.html">WGS Germline (Multi callers)</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">germline</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span><span class="no-select tagelement">vardict</span><span class="no-select tagelement">strelka</span></p>
            <p>A variant-calling WGS pipeline using GATK, VarDict and Strelka2.</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgsgermlinemulticallersvariantsonly.html">WGS Germline (Multi callers) [VARIANTS only]</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">germline</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span><span class="no-select tagelement">vardict</span><span class="no-select tagelement">strelka</span></p>
            <p>A variant-calling WGS pipeline using GATK, VarDict and Strelka2.</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgsgermlinegatk.html">WGS Germline (GATK)</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">germline</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span></p>
            <p>A variant-calling WGS pipeline using only the GATK Haplotype variant caller.</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgsgermlinegatkvariantsonly.html">WGS Germline (GATK) [VARIANTS only]</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">germline</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span></p>
            <p>A variant-calling WGS pipeline using only the GATK Haplotype variant caller.</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgssomaticmulticallers.html">WGS Somatic (Multi callers)</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">somatic</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span><span class="no-select tagelement">vardict</span><span class="no-select tagelement">strelka</span><span class="no-select tagelement">gridss</span></p>
            <p>A somatic tumor-normal variant-calling WGS pipeline using GATK, VarDict and Strelka2.</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgssomaticmulticallersvariantsonly.html">WGS Somatic (Multi callers) [VARIANTS only]</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">somatic</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span><span class="no-select tagelement">vardict</span><span class="no-select tagelement">strelka</span><span class="no-select tagelement">gridss</span></p>
            <p>A somatic tumor-normal variant-calling WGS pipeline using GATK, VarDict and Strelka2.</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgssomaticgatk.html">WGS Somatic (GATK only)</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">somatic</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span></p>
            <p>A somatic tumor-normal variant-calling WGS pipeline using only GATK Mutect2</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
        
        <div class="col-6" style="margin: 10px; padding: 20px; border: 1px solid #e3e3e3; border-radius: 5px;">
            <h4 style="margin-bottom: 10px"><a href="wgssomaticgatkvariantsonly.html">WGS Somatic (GATK only) [VARIANTS only]</a></h4>
            <p style="overflow-x: scroll;"><span class="no-select tagelement">wgs</span><span class="no-select tagelement">cancer</span><span class="no-select tagelement">somatic</span><span class="no-select tagelement">variants</span><span class="no-select tagelement">gatk</span></p>
            <p>A somatic tumor-normal variant-calling WGS pipeline using only GATK Mutect2</p>
            <p style="margin-bottom: 10px; font-size: 12px; margin-top: 0px;">Contributors: Michael Franklin, Richard Lupat, Jiaan Yu</p>
            <a class="version-button"  style="margin-bottom: 10px">
          v<b>1.4.0</b>
        </a>
        </div>
        
    </div>
